@@ -8,26 +8,26 @@
 /************************************************/
 #include <stdio.h>
 #include <math.h>
+#include <complex.h>
+#include <fftw3.h>
 #include "mk4_data.h"
-#include "type_comp.h"
 #include "param_struct.h"
 #include "pass_struct.h"
 
-delay_rate (pass, fr, rate_spectrum)
-struct type_pass *pass;
-int fr;
-complex rate_spectrum[MAXAP];
+delay_rate (struct type_pass *pass,
+            int fr,
+            complex rate_spectrum[MAXAP])
     {
     complex apval, a, fringe_spect[MAXAP*2], X[MAXAP*2];
-    complex s_mult(), c_mult(), c_add(), c_zero(), c_exp();
-    double c_mag();
-    int fl, L, ap, np, i, j, l_int, size, l_int2;
+    int fl, L, ap, np, i, j, l_int, l_int2, size;
+    static int fft_size = 0;
     int stnpol[2][4] = {0, 1, 0, 1, 0, 1, 1, 0}; // [stn][pol] = 0:L, 1:R
     double b, l_fp, frac;
     struct freq_corel *pd;
     struct data_corel *datum;
     extern struct type_param param;
     extern struct type_status status;
+    static fftw_plan fftplan;
 
     pd = pass->pass_data + fr;
     
@@ -36,10 +36,18 @@ complex rate_spectrum[MAXAP];
     size = np * 4;                      /* This is size of FFT */
                                         /* Smaller delay rate spectrum option */
     if (size > MAXAP*2) size = MAXAP*2;
+
     status.f_rate_size = size;
 
+    if (size != fft_size)               // recompute fft quantities when size changes
+        {
+        fft_size = size;
+        fftplan = fftw_plan_dft_1d (fft_size, X, X, FFTW_FORWARD, FFTW_MEASURE);
+        }
+
                                         /* Fill data array */
-    for (i = 0; i < size; i++) X[i] = c_zero();
+    for (i = 0; i < size; i++) 
+        X[i] = 0.0;
     for (ap = 0; ap < pass->num_ap; ap++)
         {
         datum = pd->data + ap + pass->ap_off;
@@ -51,10 +59,10 @@ complex rate_spectrum[MAXAP];
                                         /* When both sidebands added together, */
                                         /* we use the mean fraction */
         if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0)) frac /= 2.0;
-        X[ap] = s_mult (apval, frac);
+        X[ap] = apval * frac;
         }
      
-    FFT1 (X, size, 1, X, 1);
+    fftw_execute (fftplan);
 
     for (i = 0; i < size; i++)
         {
@@ -76,9 +84,8 @@ complex rate_spectrum[MAXAP];
         l_int2 = l_int+1;
         if (l_int < 0) l_int = 0;
         if (l_int2 > (size-1)) l_int2 = size - 1;
-        rate_spectrum[L] = s_mult (fringe_spect[l_int], (1.0 - l_fp + l_int));
-        rate_spectrum[L] = c_add (rate_spectrum[L], s_mult (fringe_spect[l_int2],
-                                                        (l_fp - l_int)));
-        msg("fr %d cmag(rate_spectrum[%d]) %f",-3,fr,L,c_mag(rate_spectrum[L]));
+        rate_spectrum[L] = fringe_spect[l_int] * (1.0 - l_fp + l_int)
+                         + fringe_spect[l_int2] * (l_fp - l_int);
+        msg("fr %d cabs(rate_spectrum[%d]) %f", -3, fr, L, cabs (rate_spectrum[L]));
         }
      }
