@@ -13,6 +13,7 @@
 #include <time.h>
 #include <math.h>
 #include <string.h>
+#include <complex.h>
 #include "param_struct.h"
 #include "pass_struct.h"
 #include "ovex.h"
@@ -63,7 +64,6 @@ void generate_text (struct scan_struct *root,
     extern char *pexec;
     extern char version_no[], progname[];
     extern char *sprint_char_arr(), *sprint_date();
-    extern double c_phase(), c_mag();
     struct stat xeq_stat;
     int i, j;
     int start_plot, limit_plot;
@@ -425,11 +425,11 @@ void generate_text (struct scan_struct *root,
         psleft (xpos, ypos, buf);
         if (i == start_plot) psleft (labelpos, ypos, "Freq (MHz)");
         ypos -= spacing;
-        sprintf (buf, "%.1f", c_phase (status.fringe[i]) * 180.0 / pi);
+        sprintf (buf, "%.1f", carg (status.fringe[i]) * 180.0 / pi);
         psleft (xpos, ypos, buf);
         if (i == start_plot) psleft (labelpos, ypos, "Phase");
         ypos -= spacing;
-        sprintf (buf, "%.1f", c_mag (status.fringe[i]));
+        sprintf (buf, "%.1f", cabs (status.fringe[i]));
         psleft (xpos, ypos, buf);
         if (i == start_plot) psleft (labelpos, ypos, "Ampl.");
         ypos -= spacing;
@@ -693,9 +693,7 @@ void generate_text (struct scan_struct *root,
                                     // combining multiple bands    rjc 2010.1.5
         if (msglev < 2)
             {
-            fprintf (stderr, "%6.1f ", fmod((double)fringe.t207->ref_pcoffset[i].lsb 
-              - (double)fringe.t207->rem_pcoffset[i].lsb
-              + c_phase (status.fringe[i]) * 180.0 / pi
+            fprintf (stderr, "%6.1f ", fmod(carg (status.fringe[i]) * 180.0 / pi
               + 360 * delta_delay * (pass->pass_data[i].frequency 
                       - fringe.t205->ref_freq), 360.0));
             }
