@@ -111,5 +111,8 @@ init_tokens ()
     tokenize (FILE_,        "file",       INT_CONST + PHYLE)
     tokenize (ADHOC_FILE_,  "adhoc_file", STRING_PARAM)
     tokenize (ADHOC_FILE_CHANS_, "adhoc_file_chans", STRING_PARAM)
+    tokenize (MBD_ANCHOR_,  "mbd_anchor", INT_PARAM)
+    tokenize (MODEL_,       "model",      INT_CONST + MODEL)
+    tokenize (SBD_,         "sbd",        INT_CONST + SBD)
     }
 
