@@ -12,21 +12,21 @@
 #include "pass_struct.h"
 #include <math.h>
 #include <stdio.h>
+#include <complex.h>
+#include <fftw3.h>
 
-int
-make_plotdata(pass)
-struct type_pass *pass;
+int make_plotdata(struct type_pass *pass)
     {
     extern struct type_param param;
     extern struct type_status status;
     extern struct type_plot plot;
     struct freq_corel *pdata;
     struct data_corel *datum;
-    complex X[2*MAXMAX], Z, sum, Y[4*MAXLAG], sbsp[MAXFREQ][2*MAXLAG], c_exp(), c_add();
-    complex c_mult(), vrot(), c_zero(), s_mult(), sum_all, sum_freq, sum_ap[MAXAP];
+    complex X[2*MAXMAX], Z, sum, Y[4*MAXLAG], sbsp[MAXFREQ][2*MAXLAG];
+    complex vrot(), sum_all, sum_freq, sum_ap[MAXAP];
     complex wght_phsr;
     int maxchan[MAXFREQ], i, j, np, fr, ap, lag, st, seg, lagbit;
-    double ap_seg, c_mag(), c_phase(), max[MAXFREQ], maxv, peak, frac,
+    double ap_seg, max[MAXFREQ], maxv, peak, frac,
                         sbdbox[MAXFREQ], rj, c, ap_cnt[MAXAP], nap,
            offset, maxamp, sumwt, q[3],
            temp[MAXAP],
@@ -40,6 +40,7 @@ struct type_pass *pass;
         return (-1);
         }
 
+    fftw_plan fftplan;
     pdata = pass->pass_data;            /* For convenience */
 
                                         /* Calculate delay rate spectrum */
@@ -52,15 +53,15 @@ struct type_pass *pass;
                                         /* first apply rotator to single band */
                                         /* delay values (at max sb delay) and */
                                         /* total sum over all freqs */
-    for (i = 0; i < MAXAP; i++) X[i] = c_zero();
+    for (i = 0; i < MAXAP; i++) 
+        X[i] = 0.0;
 
     for (fr = 0; fr < pass->nfreq; fr++)
         for(ap = pass->ap_off; ap < pass->ap_off+pass->num_ap; ap++) 
             {
             datum = pdata[fr].data + ap;
-            Z = c_mult (datum->sbdelay[status.max_delchan],
-                        vrot (ap,status.dr_max_global, status.mbd_max_global, fr,
-                                 datum->sband, pass)); 
+            Z = datum->sbdelay[status.max_delchan]
+              * vrot (ap,status.dr_max_global, status.mbd_max_global, fr, datum->sband, pass); 
                                         /* Weight by fractional AP */
             frac = 0.0;
             if (datum->usbfrac >= 0.0) frac = datum->usbfrac;
@@ -68,13 +69,14 @@ struct type_pass *pass;
                                         /* When both sidebands added together, */
                                         /* we use the mean fraction */
             if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0)) frac /= 2.0;
-            Z = s_mult (Z, frac);
+            Z = Z * frac;
 
-            X[ap-pass->ap_off] = c_add(X[ap-pass->ap_off], Z);
+            X[ap-pass->ap_off] = X[ap-pass->ap_off] + Z;
             }
                                         /* Then perform FFT over time to obtain */
                                         /* d-r spectrum avg'd over all frequencies */
-    FFT1 (X, npmax, 1, X, 1);
+    fftplan = fftw_plan_dft_1d (npmax, X, X, FFTW_FORWARD, FFTW_ESTIMATE);
+    fftw_execute (fftplan);
     for (i = 0; i < npmax; i++)
         {
         rj = (double)i - (double)(npmax/2); 
@@ -84,7 +86,7 @@ struct type_pass *pass;
         if (rj < -0.5) rj += (double)npmax;
         if (rj > (npmax - 0.5)) rj -= (double)npmax;
         j = (int)(rj + 0.5);
-        plot.d_rate[i] = c_mag (X[j]) / (double)status.total_ap_frac;   
+        plot.d_rate[i] = cabs (X[j]) / (double)status.total_ap_frac;   
         }
                                         /* adjust dr plot for effects of coherence time
                                          * if that feature has been invoked  rjc 2006.4.27 */
@@ -127,17 +129,16 @@ struct type_pass *pass;
     plot.num_mb_pts = (status.grid_points < 256) ? 256 : status.grid_points;
     for (i = 0; i < plot.num_mb_pts; i++)
         {
-        X[i] = c_zero();
-        Y[i] = c_zero();
+        X[i] = 0.0;
+        Y[i] = 0.0;
         }
     for (fr = 0; fr < pass->nfreq; fr++)
         {
         for (ap = pass->ap_off; ap < pass->ap_off+pass->num_ap; ap++)
             {
             datum = pdata[fr].data + ap;
-            Z = c_mult (datum->sbdelay[status.max_delchan],
-                vrot (ap, status.dr_max_global, 0.0, fr, 
-                                datum->sband, pass));   
+            Z = datum->sbdelay[status.max_delchan]
+              * vrot (ap, status.dr_max_global, 0.0, fr, datum->sband, pass);
                                         /* Weight by fractional AP */
             frac = 0.0;
             if (datum->usbfrac >= 0.0) 
@@ -148,26 +149,29 @@ struct type_pass *pass;
                                         /* we use the mean fraction */
             if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0)) 
                 frac /= 2.0;
-            Z = s_mult (Z, frac);
+            Z = Z * frac;
 
-            X[fr] = c_add (X[fr], Z);
+            X[fr] = X[fr] + Z;
             }                           /* Space frequencies in array for FFT */
         Y[status.mb_index[fr]] = X[fr];
         }
                                         /* FFt across freq to mbdelay spectrum */
-    FFT1(Y, plot.num_mb_pts, 1, Y, 1);
+    fftplan = fftw_plan_dft_1d (plot.num_mb_pts, Y, Y, FFTW_FORWARD, FFTW_ESTIMATE);
+    fftw_execute (fftplan);
     for (i = 0; i < plot.num_mb_pts; i++)
         {
         j = i - plot.num_mb_pts / 2;
         if (j < 0) 
             j += plot.num_mb_pts;
-        plot.mb_amp[i] = c_mag(Y[j]) / status.total_ap_frac;
+        plot.mb_amp[i] = cabs(Y[j]) / status.total_ap_frac;
         }
 
                                         /* Calculate single band delay, */
                                         /* Xpower spectrum, & sbdbox */
-    for (i = 0; i < 2*MAXLAG; i++) X[i] = c_zero();
-    for (i = 0; i < 4*MAXLAG; i++) Y[i] = c_zero();
+    for (i = 0; i < 2*MAXLAG; i++) 
+        X[i] = 0.0;
+    for (i = 0; i < 4*MAXLAG; i++) 
+        Y[i] = 0.0;
     for (i = 0; i < MAXFREQ; i++) 
         {
         max[i] = 0.0;
@@ -178,13 +182,13 @@ struct type_pass *pass;
         {
         for (fr = 0; fr < pass->nfreq; fr++)
             {
-            sum = c_zero();
+            sum = 0.0;
             for (ap = pass->ap_off; ap < pass->ap_off+pass->num_ap; ap++)
                 {
                 datum = pdata[fr].data + ap;
-                Z = c_mult (datum->sbdelay[lag],
+                Z = datum->sbdelay[lag]
+                  * vrot (ap, status.dr_max_global, status.mbd_max_global, fr, 0, pass);
                                         // sb correction made by spectral below
-                    vrot (ap, status.dr_max_global, status.mbd_max_global, fr, 0, pass));
                                         /* Weight by fractional AP */
                 frac = 0.0;
                 if (datum->usbfrac >= 0.0) frac  = datum->usbfrac;
@@ -192,32 +196,36 @@ struct type_pass *pass;
                                         /* When both sidebands added together, */
                                         /* we use the mean fraction */
                 if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0)) frac /= 2.0;
-                Z = s_mult (Z, frac);
+                Z = Z * frac;
 
-                sum = c_add (Z, sum);
+                sum = Z + sum;
                 }
                                         /* sbsp is singleband spect. for each freq */
                                         /* X is singleb sp. summed over all freq's */
             sbsp[fr][lag] = sum;
-            X[lag] = c_add( X[lag], sum);
+            X[lag] = X[lag] + sum;
                                         /* Find the max lag for each frequency */
-            if (c_mag(sum) > max[fr])
+            if (cabs(sum) > max[fr])
                 {
-                max[fr] = c_mag (sum);
+                max[fr] = cabs (sum);
                 maxchan[fr] = lag;
                 }
             }
-        plot.sb_amp[lag] = c_mag(X[lag]) / status.total_ap_frac;
+        plot.sb_amp[lag] = cabs(X[lag]) / status.total_ap_frac;
 
         if (lag == status.max_delchan)
-            status.coh_avg_phase = c_phase (X[lag]);
+            status.coh_avg_phase = carg (X[lag]);
         j = lag - nl;
-        if (j < 0) j += 4 * nl;
+        if (j < 0)
+            j += 4 * nl;
+        if (lag == 0)
+            j = 2 * nl;             // pure real lsb/dc channel goes in middle
         Y[j] = X[lag];
         }
                                         /* FFT sband spectrum -> XPower spectrum */
-    FFT1 (Y, 4 * nl, 1, Y, 1);
-                                        /* Counter rotate to eliminate sband delay */
+    fftplan = fftw_plan_dft_1d (4 * nl, Y, Y, FFTW_FORWARD, FFTW_ESTIMATE);
+    fftw_execute (fftplan);
+                                        // scale crosspower spectra for correct amplitude
     for (i = 0; i < 2*nl; i++)
        {
        j = nl - i;
@@ -231,9 +239,10 @@ struct type_pass *pass;
        if (j < 0)
            j += 4*nl;
             
-       plot.cp_spectrum[i] = s_mult (Y[j], sb_factor);
-       Z = c_exp(-(status.sbd_max * (i-nl) * M_PI / (status.sbd_sep * 2*nl)));
-       plot.cp_spectrum[i] = c_mult(Z, plot.cp_spectrum[i]);
+       plot.cp_spectrum[i] = Y[j] * sb_factor;
+                                        /* Counter rotate to eliminate sband delay */
+       Z = cexp(-I * (status.sbd_max * (i-nl) * M_PI / (status.sbd_sep * 2*nl)));
+       plot.cp_spectrum[i] = Z * plot.cp_spectrum[i];
        }
                                         /* For each freq, interpolate through */
                                         /* 3 sband delays to find sbdbox */
@@ -241,7 +250,7 @@ struct type_pass *pass;
     for (fr = 0; fr < pass->nfreq; fr++)
        {
        for (i=0; i<3; i++)
-           yy[i] = c_mag (sbsp[fr][maxchan[fr]-1+i]);
+           yy[i] = cabs (sbsp[fr][maxchan[fr]-1+i]);
        parabola (yy, -1.0, 1.0, &peak, &maxv, q);
        status.sbdbox[fr] = maxchan[fr] + peak + 1;
        }
@@ -268,15 +277,15 @@ struct type_pass *pass;
     for (i = 0; i < pass->num_ap; i++)
         {
         ap_cnt[i] = 0;
-        sum_ap[i] = c_zero();
+        sum_ap[i] = 0.0;
         }
-    sum_all = c_zero();
+    sum_all = 0.0;
                                         /* For each freq & ap, the fringe phasor */
                                         /* is the sband delay spectrum at the max */
                                         /* delay chan., rotated by vrot() */
     for (fr = 0; fr < pass->nfreq; fr++)
         {
-        sum_freq = c_zero();
+        sum_freq = 0.0;
         sumwt = 0.0;
         for (ap = pass->ap_off; ap < pass->ap_off+pass->num_ap; ap++)
             {
@@ -298,23 +307,23 @@ struct type_pass *pass;
                 if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0))
                     plot.weights[fr][ap] /= 2.0;
 
-                Z = c_mult (datum->sbdelay[status.max_delchan],
-                      vrot(ap, status.dr_max_global, status.mbd_max_global, fr, datum->sband, pass));
+                Z = datum->sbdelay[status.max_delchan]
+                  * vrot(ap,status.dr_max_global,status.mbd_max_global,fr,datum->sband,pass);
                 plot.phasor[fr][ap] = Z;
                 }
             else
-                plot.phasor[fr][ap] = c_zero();
-            wght_phsr = s_mult (plot.phasor[fr][ap], plot.weights[fr][ap]);
-            sum_all = c_add(sum_all, wght_phsr);
-            sum_freq = c_add(sum_freq, wght_phsr);
-            sum_ap[ap] = c_add(sum_ap[ap], wght_phsr);
+                plot.phasor[fr][ap] = 0.0;
+            wght_phsr = plot.phasor[fr][ap] * plot.weights[fr][ap];
+            sum_all = sum_all + wght_phsr;
+            sum_freq = sum_freq + wght_phsr;
+            sum_ap[ap] = sum_ap[ap] + wght_phsr;
             }
                                         /* Changed to reflect fractional APs */
         c = (sumwt > 0.0) ? status.amp_corr_fact/sumwt : 0.0;
 
-        status.fringe[fr] = s_mult(sum_freq, c);
-        msg ("status.fringe[%d] %f %f", 0, fr, status.fringe[fr].re, status.fringe[fr].im);
-        status.inc_avg_amp_freq += c_mag(sum_freq) * status.amp_corr_fact;
+        status.fringe[fr] = sum_freq * c;
+        msg ("status.fringe[%d] %f %f", 0, fr, status.fringe[fr]);
+        status.inc_avg_amp_freq += cabs(sum_freq) * status.amp_corr_fact;
         }
                                         // generate data for sum over all channels
     for (ap = pass->ap_off; ap < pass->ap_off+pass->num_ap; ap++)
@@ -322,7 +331,7 @@ struct type_pass *pass;
         plot.phasor[pass->nfreq][ap] = sum_ap[ap];
         plot.weights[pass->nfreq][ap] = ap_cnt[ap];
         }
-    status.coh_avg_phase = c_phase(sum_all);
+    status.coh_avg_phase = carg (sum_all);
     status.inc_avg_amp_freq /= status.total_ap_frac;
                                         /* Noise bias correction ? */
     status.inc_avg_amp_freq /= ((1.0 + 1.0/(2.0 * status.snr 
@@ -330,5 +339,6 @@ struct type_pass *pass;
    
     calc_rms (pass);
 
+    fftw_destroy_plan (fftplan);
     return(0);
     }
