@@ -50,7 +50,8 @@ int parser ()
         parsed_baseline[2],
         parsed_source[32],
         parsed_codes[MAX_CHAN_PP],
-        *psc;
+        *psc,
+        chan[2];
 
    float fval;
 
@@ -556,23 +557,37 @@ int parser ()
 
 
             case INSERT_V_CHAR:                 /* first figure out side band */
-               if (tnum == TWO_CHAR_)
+               if (tnum == ONE_CHAR_)
                    {
-                   if (char_values[tval+1] == '+')
+                   chan[0] = char_values[tval];
+                   sideband = DSB;
+                   }
+               else if (tnum == TWO_CHAR_)
+                   {
+                   memcpy (chan, char_values+tval, 2);
+                   if (chan[1] == '+')
                        sideband = USB;
-                   else if (char_values[tval+1] == '-')
+                   else if (chan[1] == '-')
                        sideband = LSB;
                    else
                        sideband = -1;                        /* denotes error */
                    }
-               else                                   /* ONE_CHAR_ by default */
-                   sideband = DSB;
+               else                                // must be an integer
+                   {
+                   if (tval >=0 && tval <= 9)
+                       {
+                       chan[0] = '0' + tval;
+                       sideband = DSB;
+                       }
+                   else
+                       chan[0] = '#';                 // null char will cause error
+                       chan[1] = '#';
+                   }
 
-               i = fcode(char_values[tval]);          /* get freq. array index */
+               i = fcode(chan[0]);                       /* get freq. array index */
                if (i<0 || i>MAX_CHAN_PP-1 || sideband<0) /* trap error conditions */
                    {
-                   msg ("Errant freq element: %c%c", 2, 
-                         char_values[tval], char_values[tval+1]);
+                   msg ("Errant freq element: %c%c", 2, chan[0], chan[1]);
                    return (-1);
                    }
                                         /* OK, load into appropriate c_blocks */
