@@ -1,8 +1,8 @@
 #ifndef PASS_STRUCT
 #define PASS_STRUCT
 
+#include <complex.h>
 #include "control.h"
-#include "type_comp.h"
 #include "mk4_data.h"
 #include "mk4_sizes.h"
 
