@@ -46,7 +46,6 @@ int pcal_interp (struct mk4_sdata *sd1,
     double realval, imagval, freq, u, v;
     char chan[9];
     char chan_buffer[MAX_CHAN_PP][9];
-    complex c_zero();
     struct freq_corel *fc;
     struct mk4_sdata *sd;
     struct type_308 *t308;
@@ -72,8 +71,8 @@ int pcal_interp (struct mk4_sdata *sd1,
             isd = &(fc->data[ap].ref_sdata);
             for (j=0; j<MAX_PCF; j++)
                 {
-                isd->phasecal_lcp[j] = c_zero();
-                isd->phasecal_rcp[j] = c_zero();
+                isd->phasecal_lcp[j] = 0.0;
+                isd->phasecal_rcp[j] = 0.0;
                 }
             isd->pcweight_lcp = 0.0;
             isd->pcweight_rcp = 0.0;
@@ -81,8 +80,8 @@ int pcal_interp (struct mk4_sdata *sd1,
             isd = &(fc->data[ap].rem_sdata);
             for (j=0; j<MAX_PCF; j++)
                 {
-                isd->phasecal_lcp[j] = c_zero();
-                isd->phasecal_rcp[j] = c_zero();
+                isd->phasecal_lcp[j] = 0.0;
+                isd->phasecal_rcp[j] = 0.0;
                 }
             isd->pcweight_lcp = 0.0;
             isd->pcweight_rcp = 0.0;
@@ -327,7 +326,7 @@ int pcal_interp (struct mk4_sdata *sd1,
                                 {
                                     // if there is DSB data, then don't allow the LSB
                                     // pcal to overwrite what is already there
-                                if (ch == LSB_LCP && isd->phasecal_lcp[ipc].re != 0.0)
+                                if (ch == LSB_LCP && cabs(isd->phasecal_lcp[ipc]) != 0.0)
                                     break;
                                     // must renormalize to account for fraction of high data
                                     // see rjc's normalization notes from 2006.10.16
@@ -340,8 +339,7 @@ int pcal_interp (struct mk4_sdata *sd1,
                                     }
                                 }
 
-                            isd->phasecal_lcp[ipc].re = -realval;
-                            isd->phasecal_lcp[ipc].im = imagval;
+                            isd->phasecal_lcp[ipc] = -realval + I * imagval;
                             if ((realval != 0.0) || (imagval != 0.0))
                                 isd->pcweight_lcp = 1.0;
                             break;
@@ -351,7 +349,7 @@ int pcal_interp (struct mk4_sdata *sd1,
                                 {
                                     // if there is DSB data, then don't allow the LSB
                                     // pcal to overwrite what is already there
-                                if (ch == LSB_RCP && isd->phasecal_rcp[ipc].re != 0.0)
+                                if (ch == LSB_RCP && cabs (isd->phasecal_rcp[ipc]) != 0.0)
                                     break;
                                     // must renormalize to account for fraction of high data
                                     // see rjc's normalization notes from 2006.10.16
@@ -364,8 +362,7 @@ int pcal_interp (struct mk4_sdata *sd1,
                                     }
                                 }
 
-                            isd->phasecal_rcp[ipc].re = -realval;
-                            isd->phasecal_rcp[ipc].im = imagval;
+                            isd->phasecal_rcp[ipc] = -realval + I * imagval;
                             if ((realval != 0.0) || (imagval != 0.0))
                                 isd->pcweight_rcp = 1.0;
                             break;
